@@ -26,13 +26,13 @@
 #include <QCheckBox>
 #include <QLabel>
 #include <qradiobutton.h>
-//#include <QtGlobal>
+#include <QStandardPaths>
 
-#include <kapplication.h>
 #include <KConfig>
-#include <KGlobal>
-#include <klocale.h>
-#include <KStandardDirs>
+#include <klocalizedstring.h>
+
+#include "dialogbase.h"
+#include "dialogstatesaver.h"
 
 #include "gui/kmixerwidget.h"
 #include "core/GlobalConfig.h"
@@ -61,12 +61,6 @@ KMixPrefDlg::KMixPrefDlg(QWidget *parent, GlobalConfig& config) :
 	setFaceType(KPageDialog::List);
 	//setCaption(i18n("Configure"));
 
-#ifndef X_KMIX_KF5_BUILD
-	setButtons(Ok | Cancel | Apply);
-
-	setDefaultButton(Ok);
-#endif
-
 	dvc = 0;
 	dvcSpacerBelow = 0;
 
@@ -80,17 +74,11 @@ KMixPrefDlg::KMixPrefDlg(QWidget *parent, GlobalConfig& config) :
 	createControlsTab();
 	updateWidgets(); // I thought KConfigDialog would call this, but I saw during a gdb session that it does not do so.
 
-#ifndef X_KMIX_KF5_BUILD
-	showButtonSeparator(true);
-#endif
-
 	generalPage = addPage(m_generalTab, i18n("General"), "configure");
 	startupPage = addPage(m_startupTab, i18n("Start"), "preferences-system-login");
 	soundmenuPage = addPage(m_controlsTab, i18n("Sound Menu"), "audio-volume-high");
-}
 
-KMixPrefDlg::~KMixPrefDlg()
-{
+	new DialogStateSaver(this);
 }
 
 /**
@@ -111,7 +99,7 @@ void KMixPrefDlg::switchToPage(KMixPrefPage page)
 		setCurrentPage(startupPage);
 		break;
 	default:
-		kWarning() << "Tried to activated unknown preferences page" << page;
+		qCWarning(KMIX_LOG) << "Tried to activated unknown preferences page" << page;
 		break;
 	}
 	show();
@@ -123,7 +111,7 @@ void KMixPrefDlg::createStartupTab()
 {
 	layoutStartupTab = new QVBoxLayout(m_startupTab);
 	layoutStartupTab->setMargin(0);
-	layoutStartupTab->setSpacing(KDialog::spacingHint());
+	layoutStartupTab->setSpacing(DialogBase::verticalSpacing());
 
 	QLabel* label = new QLabel(i18n("Startup"), m_startupTab);
 	layoutStartupTab->addWidget(label);
@@ -180,13 +168,8 @@ void KMixPrefDlg::createOrientationGroup(const QString& labelSliderOrientation,
 	connect(qrbHor, SIGNAL(toggled(bool)), SLOT(updateButtons()));
 	connect(qrbVert, SIGNAL(toggled(bool)), SLOT(updateButtons()));
 
-#ifdef X_KMIX_KF5_BUILD
     connect(button(QDialogButtonBox::Apply), SIGNAL(clicked()), SLOT(kmixConfigHasChangedEmitter()));
     connect(button(QDialogButtonBox::Ok), SIGNAL(clicked()), SLOT(kmixConfigHasChangedEmitter()));
-#else
-	connect(this, SIGNAL(applyClicked()), SLOT(kmixConfigHasChangedEmitter()));
-	connect(this, SIGNAL(okClicked()), SLOT(kmixConfigHasChangedEmitter()));
-#endif
 
 //	connect(qrbHor, SIGNAL(toggled(bool)), SLOT(settingsChangedSlot()));
 //	connect(qrbVert, SIGNAL(toggled(bool)), SLOT(settingsChangedSlot()));
@@ -196,7 +179,7 @@ void KMixPrefDlg::createGeneralTab()
 {
 	QBoxLayout* layout = new QVBoxLayout(m_generalTab);
 	layout->setMargin(0);
-	layout->setSpacing(KDialog::spacingHint());
+	layout->setSpacing(DialogBase::verticalSpacing());
 
 	// --- Behavior ---------------------------------------------------------
 	QLabel* label = new QLabel(i18n("Behavior"), m_generalTab);
@@ -236,7 +219,7 @@ void KMixPrefDlg::createGeneralTab()
 
 	// [CONFIG] Slider orientation (main window)
 	QGridLayout* orientationGrid = new QGridLayout();
-	orientationGrid->setHorizontalSpacing(KDialog::spacingHint());
+	orientationGrid->setHorizontalSpacing(DialogBase::horizontalSpacing());
 	layout->addItem(orientationGrid);
 
 	// Slider orientation (main window, and tray popup separately).
@@ -251,7 +234,7 @@ void KMixPrefDlg::createControlsTab()
 {
 	layoutControlsTab = new QVBoxLayout(m_controlsTab);
 	layoutControlsTab->setMargin(0);
-	layoutControlsTab->setSpacing(KDialog::spacingHint());
+	layoutControlsTab->setSpacing(DialogBase::verticalSpacing());
 	m_dockingChk = new QCheckBox(i18n("&Dock in system tray"), m_controlsTab);
 
 	addWidgetToLayout(m_dockingChk, layoutControlsTab, 10, i18n("Docks the mixer into the KDE system tray"),
@@ -303,7 +286,7 @@ void KMixPrefDlg::addWidgetToLayout(QWidget* widget, QBoxLayout* layout, int spa
 void KMixPrefDlg::updateWidgets()
 {
 	if (dialogConfig.data.debugConfig)
-		kDebug() << "";
+		qCDebug(KMIX_LOG) << "";
 	bool toplevelHorizontal = dialogConfig.data.getToplevelOrientation() == Qt::Horizontal;
 	_rbHorizontal->setChecked(toplevelHorizontal);
 	_rbVertical->setChecked(!toplevelHorizontal);
@@ -322,12 +305,12 @@ void KMixPrefDlg::updateSettings()
 {
 	Qt::Orientation toplevelOrientation = _rbHorizontal->isChecked() ? Qt::Horizontal : Qt::Vertical;
 	if (dialogConfig.data.debugConfig)
-		kDebug() << "toplevelOrientation" << toplevelOrientation << ", _rbHorizontal->isChecked()" << _rbHorizontal->isChecked();
+		qCDebug(KMIX_LOG) << "toplevelOrientation" << toplevelOrientation << ", _rbHorizontal->isChecked()" << _rbHorizontal->isChecked();
 	dialogConfig.data.setToplevelOrientation(toplevelOrientation);
 
 	Qt::Orientation trayOrientation = _rbTraypopupHorizontal->isChecked() ? Qt::Horizontal : Qt::Vertical;
 	if (dialogConfig.data.debugConfig)
-		kDebug() << "trayOrientation" << trayOrientation << ", _rbTraypopupHorizontal->isChecked()" << _rbTraypopupHorizontal->isChecked();
+		qCDebug(KMIX_LOG) << "trayOrientation" << trayOrientation << ", _rbTraypopupHorizontal->isChecked()" << _rbTraypopupHorizontal->isChecked();
 	dialogConfig.data.setTraypopupOrientation(trayOrientation);
 
     // Announcing MasterChanged, as the sound menu (aka ViewDockAreaPopup) primarily shows master volume(s).
@@ -359,7 +342,7 @@ bool KMixPrefDlg::hasChanged()
 	bool orientationFromConfigIsHor = dialogConfig.data.getToplevelOrientation() == Qt::Horizontal;
 	bool orientationFromWidgetIsHor = _rbHorizontal->isChecked();
 	if (dialogConfig.data.debugConfig)
-		kDebug() << "Orientation MAIN fromConfig=" << (orientationFromConfigIsHor ? "Hor" : "Vert") << ", fromWidget=" << (orientationFromWidgetIsHor ? "Hor" : "Vert");
+		qCDebug(KMIX_LOG) << "Orientation MAIN fromConfig=" << (orientationFromConfigIsHor ? "Hor" : "Vert") << ", fromWidget=" << (orientationFromWidgetIsHor ? "Hor" : "Vert");
 
 	bool changed = orientationFromConfigIsHor ^ orientationFromWidgetIsHor;
 	if (!changed)
@@ -367,7 +350,7 @@ bool KMixPrefDlg::hasChanged()
 		bool orientationFromConfigIsHor = dialogConfig.data.getTraypopupOrientation() == Qt::Horizontal;
 		orientationFromWidgetIsHor = _rbTraypopupHorizontal->isChecked();
 		if (dialogConfig.data.debugConfig)
-			kDebug() << "Orientation TRAY fromConfig=" << (orientationFromConfigIsHor ? "Hor" : "Vert") << ", fromWidget=" << (orientationFromWidgetIsHor ? "Hor" : "Vert");
+			qCDebug(KMIX_LOG) << "Orientation TRAY fromConfig=" << (orientationFromConfigIsHor ? "Hor" : "Vert") << ", fromWidget=" << (orientationFromWidgetIsHor ? "Hor" : "Vert");
 
 		changed = orientationFromConfigIsHor ^ orientationFromWidgetIsHor;
 	}
@@ -377,7 +360,7 @@ bool KMixPrefDlg::hasChanged()
 	}
 
 	if (dialogConfig.data.debugConfig)
-		kDebug() << "hasChanged=" << changed;
+		qCDebug(KMIX_LOG) << "hasChanged=" << changed;
 
 	return changed;
 }
@@ -404,15 +387,10 @@ void KMixPrefDlg::showEvent(QShowEvent * event)
 	m_volumeOverdrive->setVisible(overdriveAvailable);
 	volumeOverdriveWarning->setVisible(overdriveAvailable);
 
-    QString autostartConfigFilename = KGlobal::dirs()->findResource(
-                                      #ifdef X_KMIX_KF5_BUILD
-                                          "xdgconf-autostart",
-                                      #else
-                                          "autostart",
-                                      #endif
-                                          QString("kmix_autostart.desktop"));
+	QString autostartConfigFilename =
+		QStandardPaths::locate(QStandardPaths::GenericConfigLocation, "/autostart/kmix_autostart.desktop");
 	if (dialogConfig.data.debugConfig)
-	    kDebug() << "autostartConfigFilename = " << autostartConfigFilename;
+	    qCDebug(KMIX_LOG) << "autostartConfigFilename = " << autostartConfigFilename;
 	bool autostartFileExists = !autostartConfigFilename.isNull();
 
 	//allowAutostartWarning->setEnabled(autostartFileExists);
@@ -430,11 +408,7 @@ void KMixPrefDlg::showEvent(QShowEvent * event)
 	}
 	allowAutostart->setEnabled(autostartFileExists);
 
-#ifdef X_KMIX_KF5_BUILD
 	KConfigDialog::showEvent(event);
-#else
-	KDialog::showEvent(event);
-#endif
 }
 
 
